@@ -15,7 +15,7 @@
 """
 import unittest
 
-from zope.interface._compat import _skip_under_py3k
+from zope.interface._compat import _skip_under_py3k, _u
 
 
 class _SilencePy3Deprecations(unittest.TestCase):
@@ -34,17 +34,14 @@ class _Py3ClassAdvice(object):
 
     def _run_generated_code(self, code, globs, locs,
                             fails_under_py3k=True,
-                            warnings_under_py2=1):
+                           ):
         import warnings
         from zope.interface._compat import PYTHON3
         with warnings.catch_warnings(record=True) as log:
             warnings.resetwarnings()
             if not PYTHON3:
                 exec(code, globs, locs)
-                if warnings_under_py2:
-                    self.assertEqual(len(log), warnings_under_py2)
-                    for entry in log:
-                        self.assertEqual(entry.category, DeprecationWarning)
+                self.assertEqual(len(log), 0) # no longer warn
                 return True
             else:
                 try:
@@ -54,7 +51,38 @@ class _Py3ClassAdvice(object):
                 else:
                     if fails_under_py3k:
                         self.fail("Didn't raise TypeError")
- 
+
+
+class NamedTests(unittest.TestCase):
+
+    def test_class(self):
+        from zope.interface.declarations import named
+
+        @named(_u('foo'))
+        class Foo(object):
+            pass
+
+        self.assertEqual(Foo.__component_name__, _u('foo'))
+
+    def test_function(self):
+        from zope.interface.declarations import named
+
+        @named(_u('foo'))
+        def doFoo(object):
+            pass
+
+        self.assertEqual(doFoo.__component_name__, _u('foo'))
+
+    def test_instance(self):
+        from zope.interface.declarations import named
+
+        class Foo(object):
+            pass
+        foo = Foo()
+        named(_u('foo'))(foo)
+
+        self.assertEqual(foo.__component_name__, _u('foo'))
+
 
 class DeclarationTests(_SilencePy3Deprecations):
 
@@ -64,7 +92,7 @@ class DeclarationTests(_SilencePy3Deprecations):
 
     def _makeOne(self, *args, **kw):
         return self._getTargetClass()(*args, **kw)
- 
+
     def test_ctor_no_bases(self):
         decl = self._makeOne()
         self.assertEqual(list(decl.__bases__), [])
@@ -220,7 +248,7 @@ class DeclarationTests(_SilencePy3Deprecations):
         other = self._makeOne(IBar, IBaz)
         after = before + other
         self.assertEqual(list(after), [IFoo, IBar, IBaz])
- 
+
 
 class ImplementsTests(_SilencePy3Deprecations):
 
@@ -230,19 +258,19 @@ class ImplementsTests(_SilencePy3Deprecations):
 
     def _makeOne(self, *args, **kw):
         return self._getTargetClass()(*args, **kw)
- 
+
     def test_ctor_no_bases(self):
         impl = self._makeOne()
         self.assertEqual(impl.inherit, None)
         self.assertEqual(impl.declared, ())
         self.assertEqual(impl.__name__, '?')
         self.assertEqual(list(impl.__bases__), [])
- 
+
     def test___repr__(self):
         impl = self._makeOne()
         impl.__name__ = 'Testing'
         self.assertEqual(repr(impl), '<implementedBy Testing>')
- 
+
     def test___reduce__(self):
         from zope.interface.declarations import implementedBy
         impl = self._makeOne()
@@ -677,8 +705,7 @@ class Test_implementsOnly(_SilencePy3Deprecations, _Py3ClassAdvice):
                 Foo = locs['Foo']
                 spec = Foo.__implemented__
                 self.assertEqual(list(spec), [IFoo])
-                self.assertEqual(len(log), 1)
-                self.assertEqual(log[0].category, DeprecationWarning)
+                self.assertEqual(len(log), 0) # no longer warn
 
     def test_called_once_from_class_w_bases(self):
         from zope.interface.declarations import implements
@@ -698,7 +725,7 @@ class Test_implementsOnly(_SilencePy3Deprecations, _Py3ClassAdvice):
             'class Bar(Foo):'
             '    implementsOnly(IBar)',
             ])
-        if self._run_generated_code(CODE, globs, locs, warnings_under_py2=2):
+        if self._run_generated_code(CODE, globs, locs):
             Bar = locs['Bar']
             spec = Bar.__implemented__
             self.assertEqual(list(spec), [IBar])
@@ -721,13 +748,12 @@ class Test_implements(_SilencePy3Deprecations, _Py3ClassAdvice):
             'def foo():',
             '    implements(IFoo)'
             ])
-        if self._run_generated_code(CODE, globs, locs, False, 0):
+        if self._run_generated_code(CODE, globs, locs, False):
             foo = locs['foo']
             with warnings.catch_warnings(record=True) as log:
                 warnings.resetwarnings()
                 self.assertRaises(TypeError, foo)
-                self.assertEqual(len(log), 1)
-                self.assertEqual(log[0].category, DeprecationWarning)
+                self.assertEqual(len(log), 0) # no longer warn
 
     def test_called_twice_from_class(self):
         import warnings
@@ -749,9 +775,7 @@ class Test_implements(_SilencePy3Deprecations, _Py3ClassAdvice):
                 exec(CODE, globs, locs)
             except TypeError:
                 if not PYTHON3:
-                    self.assertEqual(len(log), 2)
-                    for entry in log:
-                        self.assertEqual(entry.category, DeprecationWarning)
+                    self.assertEqual(len(log), 0) # no longer warn
             else:
                 self.fail("Didn't raise TypeError")
 
@@ -1155,8 +1179,7 @@ class Test_classProvides(_SilencePy3Deprecations, _Py3ClassAdvice):
             warnings.resetwarnings()
             self.assertRaises(TypeError, foo)
             if not PYTHON3:
-                self.assertEqual(len(log), 1)
-                self.assertEqual(log[0].category, DeprecationWarning)
+                self.assertEqual(len(log), 0) # no longer warn
 
     def test_called_twice_from_class(self):
         import warnings
@@ -1178,9 +1201,7 @@ class Test_classProvides(_SilencePy3Deprecations, _Py3ClassAdvice):
                 exec(CODE, globs, locs)
             except TypeError:
                 if not PYTHON3:
-                    self.assertEqual(len(log), 2)
-                    for entry in log:
-                        self.assertEqual(entry.category, DeprecationWarning)
+                    self.assertEqual(len(log), 0) # no longer warn
             else:
                 self.fail("Didn't raise TypeError")
 
